# SignalWire Python


![PyPI Version](https://img.shields.io/pypi/v/signalwire.svg?color=brightgreen)
![Drone CI](https://ci.signalwire.com/api/badges/signalwire/signalwire-python/status.svg)

The Relay SDK for Python enables developers to connect and use SignalWire's Relay APIs within their own Python code. Our Relay SDK allows developers to build or add robust and innovative communication services to their applications.

## Getting Started

Read the implementation documentation, guides and API Reference at the official [Relay SDK for Python Documentation](https://docs.signalwire.com/topics/relay-sdk-python) site.

---

## Contributing

Relay SDK for Python is open source and maintained by the SignalWire team, but we are very grateful for [everyone](https://github.com/signalwire/signalwire-python/contributors) who has contributed and assisted so far.

If you'd like to contribute, feel free to visit our [Slack channel](https://signalwire.community/) and read our developer section to get the code running in your local environment.

## Developers

To setup the dev environment follow these steps:

1. Fork this repository and clone it.
2. Create a new branch from `master` for your change.
3. Make changes!

## Versioning

Relay SDK for Python follows Semantic Versioning 2.0 as defined at <http://semver.org>.

## License

Relay SDK for Python is copyright © 2018-2019
[SignalWire](http://signalwire.com). It is free software, and may be redistributed under the terms specified in the [MIT-LICENSE](https://github.com/signalwire/signalwire-python/blob/master/LICENSE) file.
